


#load R/qtl

library(qtl)

# See http://www.rqtl.org/ for more info

# Reading in the data from the greenhouse environment:

GHSpMa <- read.cross("csv", dir="","AlyrataSpMaGH.csv",na.strings = "NA",genotypes=NULL,sep=";")

# Summarize data set:
summary (GHSpMa )

#### GENOTYPE PROBABILITIES ####

# Calculate genotype probabilities and add to file:
GHSpMa <- calc.genoprob(GHSpMa, step=2, off.end=0, error.prob=0.001,
  map.function="kosambi", stepwidth="fixed")

#### SIMULATED GENOTYPES ####

#  Simulate genotypes (allows use of pseudomarkers in effects plot:
GHSpMa<- sim.geno(GHSpMa, n.draws=128, step=2, off.end=0, error.prob=0.001,
  map.function="kosambi", stepwidth="fixed")

Cross <- pull.pheno(GHSpMa, "Cytop")

# GENOME-WIDE QTL ANALYSIS RUNS
# scanone and permutations
# A different set of digits into seednum has been used for each trait

#Flowering start

# Setting the seed value:
seednum <- 997351126

# Running permutations for two models with identical seed values:
set.seed(seednum)
floweringtime.Cross.PermAC <- scanone(GHSpMa, pheno.col="floweringtime",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(floweringtime.Cross.PermAC, alpha=c(0.05,0.10))

set.seed(seednum)
floweringtime.Cross.PermIC <- scanone(GHSpMa, pheno.col="floweringtime",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(floweringtime.Cross.PermIC, alpha=c(0.05,0.10))

# The following makes a data frame with the differences in the lods from the 
# corresponding permutations, and runs summary to get difference threshold:
floweringtime.Cross.PermDiff <- floweringtime.Cross.PermIC - floweringtime.Cross.PermAC
summary(floweringtime.Cross.PermDiff)

# This runs scanone to map QTLs under additive and interactive models:
floweringtime.Cross.ScanAC <- scanone(GHSpMa, pheno.col="floweringtime", model="normal",
  method="hk", addcovar=Cross)
summary(floweringtime.Cross.ScanAC, perm=floweringtime.Cross.PermAC, df=TRUE)
floweringtime.Cross.ScanIC <- scanone(GHSpMa, pheno.col="floweringtime", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(floweringtime.Cross.ScanIC, perm=floweringtime.Cross.PermIC, df=TRUE)

#Inflorescence shoots 

seednum <- 541176145

set.seed(seednum)
flstalks.Cross.PermAC <- scanone(GHSpMa, pheno.col="flstalks",
  model="normal", method="hk", addcovar=Cross, n.perm=1000)
ACthresh <- summary(flstalks.Cross.PermAC, alpha=c(0.05,0.10))

set.seed(seednum)
flstalks.Cross.PermIC <- scanone(GHSpMa, pheno.col="flstalks",
  model="normal", method="hk", addcovar=Cross,
  intcovar=Cross, n.perm=1000)
ICthresh <- summary(flstalks.Cross.PermIC, alpha=c(0.05,0.10))

#  Make a data frame with the differences in the lods from the corresponding
#    permutations, and run summary to get difference threshold:
flstalks.Cross.PermDiff <- flstalks.Cross.PermIC - flstalks.Cross.PermAC
summary(flstalks.Cross.PermDiff)

# Run scanone to map QTLs under additive and interactive models:
flstalks.Cross.ScanAC <- scanone(GHSpMa, pheno.col="flstalks", model="normal",
  method="hk", addcovar=Cross)
summary(flstalks.Cross.ScanAC, perm=flstalks.Cross.PermAC, df=TRUE)
flstalks.Cross.ScanIC <- scanone(GHSpMa, pheno.col="flstalks", model="normal",
  method="hk", addcovar=Cross, intcovar=Cross)
summary(flstalks.Cross.ScanIC, perm=flstalks.Cross.PermIC, df=TRUE)

#GENERATING SUMMARIES OF QTL-EFFECTS

floweringtime.LOD.AC <- summary(floweringtime.Cross.ScanAC, perms=floweringtime.Cross.PermAC,alpha=0.05)
flstalks.LOD.AC <- summary(flstalks.Cross.ScanAC, perms=flstalks.Cross.PermAC,alpha=0.05)

#GENERATING SUMMARIES OF QTL WITH CYTOPLASMIC INTERACTIONS

floweringtime.LOD.IC <- summary(floweringtime.Cross.ScanIC-floweringtime.Cross.ScanAC, perms=floweringtime.Cross.PermDiff,alpha=0.05)
flstalks.LOD.IC <- summary(flstalks.Cross.ScanIC-flstalks.Cross.ScanAC, perms=flstalks.Cross.PermDiff,alpha=0.05)

#GENOME-WIDE SIGNIFICANT QTL PEAKS

#QTL WITH MAIN EFFECTS
floweringtime.LOD.AC
flstalks.LOD.AC

#QTL x CYTOPLASM-INTERACTION

floweringtime.LOD.IC 
flstalks.LOD.IC 


#TESTING FOR SIGNIFICANCE AND SIZE OF ADDITIVE AND DOMINANCE EFFECTS AT GENOME-WIDE SIGNIFICANT PEAKS
#(ESTIMATED ALSO SEPARATELY FOR PLANTS WITH DIFFERENT CYTOPLASMIC BACKGROUNDS IN CASES OF QTL X CYTOPL. INTERACTIONS)

#CUSTOM SCRIPT FOR ESTIMATING ADDITIVE AND DOMINANCE EFFECTS

adimodel <- function(cross,chr,pos,trait,covariate,additive=FALSE,
  family="gaussian") {
traitval <- trait
if(is.character(trait)) {traitval <- pull.pheno(cross,trait)}
covval <- covariate
if(is.character(covariate)) {covval <- pull.pheno(cross,covariate)}
geno <- data.frame(cross$geno[[chr]]$prob[,pos,])
geno$a <- geno$AC - geno$BD
geno$d <- (geno$BC + geno$AD - geno$AC - geno$BD)/2
geno$i <- geno$BC - geno$AD

testmod <- glm(traitval ~ a + d + i, data=geno, family=family)
s.testmod <- summary(testmod)

testmod2 <- glm(traitval  ~ a + d + i + covval,
  data=geno, family=family)
s.testmod2 <- summary(testmod2)

testmod3 <- glm(traitval  ~ (a + d + i) * covval,
  data=geno, family=family)
s.testmod3 <- summary(testmod3)
if(family=="gaussian") {
 a.testmod <- anova(testmod,testmod2,testmod3, test="F")
 }
 else {
 a.testmod <- anova(testmod,testmod2,testmod3, test="Chisq")
}
# If additive=TRUE, only output is additive coeff and SE for testmod2.
# If additive=FALSE, generate full summaries of a,d,i model output
#  for all three models plus anova.
if(additive==TRUE){
 output <- s.testmod2$coefficients[2,c(1,2)]
 }
 else {
output <- list(s.testmod, s.testmod2, s.testmod3, a.testmod)
 }
return(output)
}

#LG1
adimodel(GHSpMa, chr=1, pos="PHYA", trait="floweringtime",covariate="Cytop", additive=F)

#LG2
adimodel(GHSpMa, chr=2, pos="loc26", trait="floweringtime",covariate="Cytop", additive=F)
adimodel(GHSpMa, chr=2, pos="loc32", trait="flstalks",covariate="Cytop", additive=F)

#LG3
adimodel(GHSpMa, chr=3, pos="loc6", trait="floweringtime",covariate="Cytop", additive=F)

#LG4
adimodel(GHSpMa, chr=4, pos="loc24", trait="floweringtime",covariate="Cytop", additive=F)

#LG6
adimodel(GHSpMa, chr=6, pos="loc4", trait="floweringtime",covariate="Cytop", additive=F)
adimodel(GHSpMa, chr=6, pos="loc48", trait="flstalks",covariate="Cytop", additive=F)

#LG8
adimodel(GHSpMa, chr=8, pos="loc44", trait="floweringtime",covariate="Cytop", additive=F)

###SINGLE-MARKER TESTS FOR PUTATIVE QTL EFFECTS

##ADDITIVE QTL (TESTED IF ADDITIVE QTL WAS FOUND IN ANOTHER ENVIRONMENT

#TESTING FOR SIGNIFICANCE OF QTL MAIN EFFECT AND ADDITIVE EFFECT

#LG1
LG1_flstalks_M_loc52<- makeqtl(GHSpMa,1, 52, what="prob")
summary(LG1_flstalks_M_loc52)
LG1_flstalks_M_loc52_qtl <- fitqtl(GHSpMa, LG1_flstalks_M_loc52, pheno.col="flstalks", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG1_flstalks_M_loc52_qtl)
adimodel(GHSpMa, chr=1, pos="loc52", trait="flstalks",covariate="Cytop", additive=F)

#LG4
LG4_floweringtime_M_loc24<- makeqtl(GHSpMa,4, 24, what="prob")
summary(LG4_floweringtime_M_loc24)
LG4_floweringtime_M_loc24_qtl <- fitqtl(GHSpMa, LG4_floweringtime_M_loc24, pheno.col="floweringtime", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG4_floweringtime_M_loc24_qtl)
adimodel(GHSpMa, chr=4, pos="loc24", trait="floweringtime",covariate="Cytop", additive=F)

#LG7
LG7_floweringtime_M_loc0<- makeqtl(GHSpMa,7, 0, what="prob")
summary(LG7_floweringtime_M_loc0)
LG7_floweringtime_M_loc0_qtl <- fitqtl(GHSpMa, LG7_floweringtime_M_loc0, pheno.col="floweringtime", formula=y~Q1, method="hk", get.ests=TRUE)
summary(LG7_floweringtime_M_loc0_qtl)
adimodel(GHSpMa, chr=7, pos="AT4G39680", trait="floweringtime",covariate="Cytop", additive=F)



#BAYESIAN 95% INTERVALS FOR GENOME-WIDE SIGNIFICANT AND PUTATIVE QTL

#LG1
bayesint (floweringtime.Cross.ScanAC, chr=1, prob=0.95, lodcolumn=1)

#LG2
bayesint (floweringtime.Cross.ScanAC, chr=2, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (flstalks.Cross.ScanAC, chr=2, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LG3
bayesint (floweringtime.Cross.ScanAC, chr=3, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LG4
bayesint (flstalks.Cross.ScanAC, chr=4, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (floweringtime.Cross.ScanAC, chr=4, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LG6
bayesint (floweringtime.Cross.ScanAC, chr=6, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)
bayesint (flstalks.Cross.ScanAC, chr=6, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LG7
bayesint (floweringtime.Cross.ScanAC, chr=7, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LG8
bayesint (floweringtime.Cross.ScanAC, chr=8, prob=0.95, lodcolumn=1, expandtomarkers=FALSE)

#LOD profile figures in the supplemental material:

plot(floweringtime.Cross.ScanAC, col="black", lty=1,ylab="LOD",lwd=4, ylim=c(0,6),main="Flowering start in the greenhouse", xlab="LG")
add.threshold(floweringtime.Cross.ScanAC, perms=floweringtime.Cross.PermAC,alpha=0.05, col="black", lwd=4,lty=1)

plot(floweringtime.Cross.ScanIC-floweringtime.Cross.ScanAC, lty=1,lwd=4, ylim=c(0,6),main="Flowering start in the greenhouse", xlab="LG")
add.threshold(floweringtime.Cross.ScanIC-floweringtime.Cross.ScanAC, perms=floweringtime.Cross.PermDiff,alpha=0.05, col="black",lwd=4, lty=1)

plot(flstalks.Cross.ScanAC, col="black", lty=1,ylab="LOD", lwd=4,ylim=c(0,6), main="# infl. shoots in the greenhouse", xlab="LG")
add.threshold(flstalks.Cross.ScanAC, perms=flstalks.Cross.PermAC,alpha=0.05, col="black",lwd=4, lty=1)

plot(flstalks.Cross.ScanIC-flstalks.Cross.ScanAC, lty=1,lwd=4, ylim=c(0,4), main="# infl. shoots in the greenhouse", xlab="LG")
add.threshold(flstalks.Cross.ScanIC-flstalks.Cross.ScanAC, perms=flstalks.Cross.PermDiff,alpha=0.05, col="black", lwd=4,lty=1)

